@@ -15,6 +15,7 @@ DEFAULT_KINDS = [
     # Do not sort this list, order matters.
     {"jinja2": "**/*.j2"},  # jinja2 templates are not always parsable as something else
     {"jinja2": "**/*.j2.*"},
+    {"inventory": "**/inventory/**.yml"},
     {"requirements": "**/meta/requirements.yml"},  # v1 only
     # https://docs.ansible.com/ansible/latest/dev_guide/collections_galaxy_meta.html
     {"galaxy": "**/galaxy.yml"},  # Galaxy collection meta
@@ -59,7 +60,7 @@ BASE_KINDS = [
 
 
 options = Namespace(
-    cache_dir=".cache",
+    cache_dir=None,
     colored=True,
     configured=False,
     cwd=".",
@@ -120,12 +121,14 @@ def ansible_collections_path() -> str:
 
 def parse_ansible_version(stdout: str) -> Tuple[str, Optional[str]]:
     """Parse output of 'ansible --version'."""
+    # Ansible can produce extra output before displaying version in debug mode.
+
     # ansible-core 2.11+: 'ansible [core 2.11.3]'
-    match = re.match(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout)
+    match = re.search(r"^ansible \[(?:core|base) ([^\]]+)\]", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     # ansible-base 2.10 and Ansible 2.9: 'ansible 2.x.y'
-    match = re.match(r"^ansible ([^\s]+)", stdout)
+    match = re.search(r"^ansible ([^\s]+)", stdout, re.MULTILINE)
     if match:
         return match.group(1), None
     return "", "FATAL: Unable parse ansible cli version: %s" % stdout
@@ -159,7 +162,3 @@ def ansible_version(version: str = "") -> Version:
             )
             sys.exit(ANSIBLE_MISSING_RC)
     return Version(version)
-
-
-if ansible_collections_path() in os.environ:
-    collection_list = os.environ[ansible_collections_path()].split(':')
