@@ -18,33 +18,28 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from typing import Any, Dict, Union
+from typing import TYPE_CHECKING, Any, Dict, Union
 
 from ansiblelint.rules import AnsibleLintRule
 
+if TYPE_CHECKING:
+    from typing import Optional
+
+    from ansiblelint.file_utils import Lintable
+
 
 class TaskHasNameRule(AnsibleLintRule):
-    id = 'unnamed-task'
-    shortdesc = 'All tasks should be named'
+    id = "unnamed-task"
+    shortdesc = "All tasks should be named"
     description = (
-        'All tasks should have a distinct name for readability '
-        'and for ``--start-at-task`` to work'
+        "All tasks should have a distinct name for readability "
+        "and for ``--start-at-task`` to work"
     )
-    severity = 'MEDIUM'
-    tags = ['idiom']
-    version_added = 'historic'
+    severity = "MEDIUM"
+    tags = ["idiom"]
+    version_added = "historic"
 
-    _nameless_tasks = [
-        'meta',
-        'debug',
-        'include_role',
-        'import_role',
-        'include_tasks',
-        'import_tasks',
-    ]
-
-    def matchtask(self, task: Dict[str, Any]) -> Union[bool, str]:
-        return (
-            not task.get('name')
-            and task["action"]["__ansible_module__"] not in self._nameless_tasks
-        )
+    def matchtask(
+        self, task: Dict[str, Any], file: "Optional[Lintable]" = None
+    ) -> Union[bool, str]:
+        return not task.get("name")
