@@ -4,14 +4,14 @@ from ansiblelint.rules import AnsibleLintRule
 
 
 class TaskNoLocalAction(AnsibleLintRule):
-    id = 'deprecated-local-action'
+    id = "deprecated-local-action"
     shortdesc = "Do not use 'local_action', use 'delegate_to: localhost'"
-    description = 'Do not use ``local_action``, use ``delegate_to: localhost``'
-    severity = 'MEDIUM'
-    tags = ['deprecations']
-    version_added = 'v4.0.0'
+    description = "Do not use ``local_action``, use ``delegate_to: localhost``"
+    severity = "MEDIUM"
+    tags = ["deprecations"]
+    version_added = "v4.0.0"
 
     def match(self, line: str) -> bool:
-        if 'local_action' in line:
+        if "local_action" in line:
             return True
         return False
