@@ -24,7 +24,8 @@ from functools import lru_cache
 from itertools import product
 from typing import TYPE_CHECKING, Any, Generator, List, Optional, Sequence
 
-import ruamel.yaml
+# Module 'ruamel.yaml' does not explicitly export attribute 'YAML'; implicit reexport disabled
+from ruamel.yaml import YAML  # type: ignore
 
 from ansiblelint.config import used_old_tags
 from ansiblelint.constants import RENAMED_TAGS
@@ -61,14 +62,14 @@ def append_skipped_rules(
     :param pyyaml_data: file text parsed via ansible and pyyaml.
     :param file_text: raw file text.
     :param file_type: type of file: tasks, handlers or meta.
-    :returns: original pyyaml_data altered with a 'skipped_rules' list added
-    to individual tasks, or added to the single metadata block.
+    :returns: original pyyaml_data altered with a 'skipped_rules' list added \
+              to individual tasks, or added to the single metadata block.
     """
     try:
         yaml_skip = _append_skipped_rules(pyyaml_data, lintable)
     except RuntimeError:
         # Notify user of skip error, do not stop, do not change exit code
-        _logger.error('Error trying to append skipped rules', exc_info=True)
+        _logger.error("Error trying to append skipped rules", exc_info=True)
         return pyyaml_data
 
     if not yaml_skip:
@@ -79,14 +80,14 @@ def append_skipped_rules(
 
 @lru_cache(maxsize=128)
 def load_data(file_text: str) -> Any:
-    """Parse `file_text` as yaml and return parsed structure.
+    """Parse ``file_text`` as yaml and return parsed structure.
 
     This is the main culprit for slow performance, each rule asks for loading yaml again and again
-    ideally the `maxsize` on the decorator above MUST be great or equal total number of rules
+    ideally the ``maxsize`` on the decorator above MUST be great or equal total number of rules
     :param file_text: raw text to parse
     :return: Parsed yaml
     """
-    yaml = ruamel.yaml.YAML()
+    yaml = YAML()
     return yaml.load(file_text)
 
 
@@ -96,15 +97,15 @@ def _append_skipped_rules(
     # parse file text using 2nd parser library
     ruamel_data = load_data(lintable.content)
 
-    if lintable.kind == 'meta':
-        pyyaml_data[0]['skipped_rules'] = _get_rule_skips_from_yaml(ruamel_data)
+    if lintable.kind in ["yaml", "requirements", "vars", "meta", "reno"]:
+        pyyaml_data[0]["skipped_rules"] = _get_rule_skips_from_yaml(ruamel_data)
         return pyyaml_data
 
     # create list of blocks of tasks or nested tasks
-    if lintable.kind in ('tasks', 'handlers'):
+    if lintable.kind in ("tasks", "handlers"):
         ruamel_task_blocks = ruamel_data
         pyyaml_task_blocks = pyyaml_data
-    elif lintable.kind == 'playbook':
+    elif lintable.kind == "playbook":
         try:
             pyyaml_task_blocks = _get_task_blocks_from_playbook(pyyaml_data)
             ruamel_task_blocks = _get_task_blocks_from_playbook(ruamel_data)
@@ -113,8 +114,6 @@ def _append_skipped_rules(
             # assume it is a playbook, check needs to be added higher in the
             # call stack, and can remove this except
             return pyyaml_data
-    elif lintable.kind in ['yaml', 'requirements', 'vars', 'meta', 'reno']:
-        return pyyaml_data
     else:
         # For unsupported file types, we return empty skip lists
         return None
@@ -130,9 +129,9 @@ def _append_skipped_rules(
         if not pyyaml_task and not ruamel_task:
             continue
 
-        if pyyaml_task.get('name') != ruamel_task.get('name'):
-            raise RuntimeError('Error in matching skip comment to a task')
-        pyyaml_task['skipped_rules'] = _get_rule_skips_from_yaml(ruamel_task)
+        if pyyaml_task.get("name") != ruamel_task.get("name"):
+            raise RuntimeError("Error in matching skip comment to a task")
+        pyyaml_task["skipped_rules"] = _get_rule_skips_from_yaml(ruamel_task)
 
     return pyyaml_data
 
@@ -144,10 +143,10 @@ def _get_task_blocks_from_playbook(playbook: Sequence[Any]) -> List[Any]:
     :returns: list of task dictionaries.
     """
     PLAYBOOK_TASK_KEYWORDS = [
-        'tasks',
-        'pre_tasks',
-        'post_tasks',
-        'handlers',
+        "tasks",
+        "pre_tasks",
+        "post_tasks",
+        "handlers",
     ]
 
     task_blocks = []
@@ -159,9 +158,9 @@ def _get_task_blocks_from_playbook(playbook: Sequence[Any]) -> List[Any]:
 def _get_tasks_from_blocks(task_blocks: Sequence[Any]) -> Generator[Any, None, None]:
     """Get list of tasks from list made of tasks and nested tasks."""
     NESTED_TASK_KEYS = [
-        'block',
-        'always',
-        'rescue',
+        "block",
+        "always",
+        "rescue",
     ]
 
     def get_nested_tasks(task: Any) -> Generator[Any, None, None]:
@@ -183,7 +182,7 @@ def _get_rule_skips_from_yaml(yaml_input: Sequence[Any]) -> Sequence[Any]:
     def traverse_yaml(obj: Any) -> None:
         yaml_comment_obj_strs.append(str(obj.ca.items))
         if isinstance(obj, dict):
-            for key, val in obj.items():
+            for _, val in obj.items():
                 if isinstance(val, (dict, list)):
                     traverse_yaml(val)
         elif isinstance(obj, list):
@@ -197,7 +196,7 @@ def _get_rule_skips_from_yaml(yaml_input: Sequence[Any]) -> Sequence[Any]:
 
     rule_id_list = []
     for comment_obj_str in yaml_comment_obj_strs:
-        for line in comment_obj_str.split(r'\n'):
+        for line in comment_obj_str.split(r"\n"):
             rule_id_list.extend(get_rule_skips_from_line(line))
 
     return [normalize_tag(tag) for tag in rule_id_list]
