@@ -14,11 +14,11 @@ def test_unjinja() -> None:
     assert AnsibleLintRule.unjinja(text) == output
 
 
-@pytest.mark.parametrize('rule_config', (dict(), dict(foo=True, bar=1)))
+@pytest.mark.parametrize("rule_config", (dict(), dict(foo=True, bar=1)))
 def test_rule_config(rule_config: Dict[str, Any], monkeypatch: MonkeyPatch) -> None:
     """Check that a rule config is inherited from options."""
-    rule_id = 'rule-0'
-    monkeypatch.setattr(AnsibleLintRule, 'id', rule_id)
+    rule_id = "rule-0"
+    monkeypatch.setattr(AnsibleLintRule, "id", rule_id)
     monkeypatch.setitem(options.rules, rule_id, rule_config)
 
     rule = AnsibleLintRule()
