@@ -27,20 +27,37 @@ from ansiblelint.rules import AnsibleLintRule
 
 
 class TestFormatter(unittest.TestCase):
-
-    def setUp(self):
+    def setUp(self) -> None:
         self.rule = AnsibleLintRule()
         self.rule.id = "TCF0001"
-        self.formatter = Formatter(pathlib.Path.cwd(), True)
+        self.formatter = Formatter(pathlib.Path.cwd(), display_relative_path=True)
 
-    def test_format_coloured_string(self):
-        match = MatchError("message", 1, "hello", "filename.yml", self.rule)
-        self.formatter.format(match, True)
+    def test_format_coloured_string(self) -> None:
+        match = MatchError(
+            message="message",
+            linenumber=1,
+            details="hello",
+            filename="filename.yml",
+            rule=self.rule,
+        )
+        self.formatter.format(match)
 
-    def test_unicode_format_string(self):
-        match = MatchError(u'\U0001f427', 1, "hello", "filename.yml", self.rule)
-        self.formatter.format(match, False)
+    def test_unicode_format_string(self) -> None:
+        match = MatchError(
+            message="\U0001f427",
+            linenumber=1,
+            details="hello",
+            filename="filename.yml",
+            rule=self.rule,
+        )
+        self.formatter.format(match)
 
-    def test_dict_format_line(self):
-        match = MatchError("xyz", 1, {'hello': 'world'}, "filename.yml", self.rule,)
-        self.formatter.format(match, True)
+    def test_dict_format_line(self) -> None:
+        match = MatchError(
+            message="xyz",
+            linenumber=1,
+            details={"hello": "world"},  # type: ignore
+            filename="filename.yml",
+            rule=self.rule,
+        )
+        self.formatter.format(match)
