@@ -20,24 +20,28 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
+from pathlib import Path
+
 import pytest
+from _pytest.fixtures import SubRequest
 
 from ansiblelint.file_utils import Lintable
+from ansiblelint.runner import Runner
 
 FAIL_TASK_1LN = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: one-level nesting
       set_fact:
         var_one: "2*(1+2) is {{ 2 * {{ 1 + 2 }} }}"
-''',
+""",
 )
 
 FAIL_TASK_1LN_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: one-level multiline nesting
@@ -46,23 +50,23 @@ FAIL_TASK_1LN_M = Lintable(
           2*(1+2) is {{ 2 *
           {{ 1 + 2 }}
           }}
-''',
+""",
 )
 
 FAIL_TASK_2LN = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: two-level nesting
       set_fact:
         var_two: "2*(1+(3-1)) is {{ 2 * {{ 1 + {{ 3 - 1 }} }} }}"
-''',
+""",
 )
 
 FAIL_TASK_2LN_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: two-level multiline nesting
@@ -72,23 +76,23 @@ FAIL_TASK_2LN_M = Lintable(
           {{ 1 +
           {{ 3 - 1 }}
           }} }}
-''',
+""",
 )
 
 FAIL_TASK_W_5LN = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: five-level wild nesting
       set_fact:
         var_three_wld: "{{ {{ {{ {{ {{ 234 }} }} }} }} }}"
-''',
+""",
 )
 
 FAIL_TASK_W_5LN_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: five-level wild multiline nesting
@@ -103,23 +107,23 @@ FAIL_TASK_W_5LN_M = Lintable(
           }}
           }}
           }}
-''',
+""",
 )
 
 SUCCESS_TASK_P = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: non-nested example
       set_fact:
         var_one: "number for 'one' is {{ 2 * 1 }}"
-''',
+""",
 )
 
 SUCCESS_TASK_P_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: multiline non-nested example
@@ -127,23 +131,23 @@ SUCCESS_TASK_P_M = Lintable(
         var_one_ml: >
           number for 'one' is {{
           2 * 1 }}
-''',
+""",
 )
 
 SUCCESS_TASK_2P = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: nesting far from each other
       set_fact:
         var_two: "number for 'two' is {{ 2 * 1 }} and number for 'three' is {{ 4 - 1 }}"
-''',
+""",
 )
 
 SUCCESS_TASK_2P_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: multiline nesting far from each other
@@ -152,23 +156,23 @@ SUCCESS_TASK_2P_M = Lintable(
           number for 'two' is {{ 2 * 1
           }} and number for 'three' is {{
           4 - 1 }}
-''',
+""",
 )
 
 SUCCESS_TASK_C_2P = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: nesting close to each other
       set_fact:
         var_three: "number for 'ten' is {{ 2 - 1 }}{{ 3 - 3 }}"
-''',
+""",
 )
 
 SUCCESS_TASK_C_2P_M = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: multiline nesting close to each other
@@ -177,23 +181,23 @@ SUCCESS_TASK_C_2P_M = Lintable(
           number for 'ten' is {{
           2 - 1
           }}{{ 3 - 3 }}
-''',
+""",
 )
 
 SUCCESS_TASK_PRINT = Lintable(
-    'playbook.yml',
-    '''\
+    "playbook.yml",
+    """\
 - hosts: all
   tasks:
     - name: print curly braces
       debug:
         msg: docker image inspect my_image --format='{{'{{'}}.Size{{'}}'}}'
-''',
+""",
 )
 
 
 @pytest.fixture
-def _playbook_file(tmp_path, request):
+def _playbook_file(tmp_path: Path, request: SubRequest) -> None:
     if request.param is None:
         return
     for play_file in request.param:
@@ -202,49 +206,51 @@ def _playbook_file(tmp_path, request):
 
 
 @pytest.mark.parametrize(
-    '_playbook_file',
+    "_playbook_file",
     (
-        pytest.param([FAIL_TASK_1LN], id='file includes one-level nesting'),
-        pytest.param([FAIL_TASK_1LN_M], id='file includes one-level multiline nesting'),
-        pytest.param([FAIL_TASK_2LN], id='file includes two-level nesting'),
-        pytest.param([FAIL_TASK_2LN_M], id='file includes two-level multiline nesting'),
-        pytest.param([FAIL_TASK_W_5LN], id='file includes five-level wild nesting'),
+        pytest.param([FAIL_TASK_1LN], id="file includes one-level nesting"),
+        pytest.param([FAIL_TASK_1LN_M], id="file includes one-level multiline nesting"),
+        pytest.param([FAIL_TASK_2LN], id="file includes two-level nesting"),
+        pytest.param([FAIL_TASK_2LN_M], id="file includes two-level multiline nesting"),
+        pytest.param([FAIL_TASK_W_5LN], id="file includes five-level wild nesting"),
         pytest.param(
-            [FAIL_TASK_W_5LN_M], id='file includes five-level wild multiline nesting'
+            [FAIL_TASK_W_5LN_M], id="file includes five-level wild multiline nesting"
         ),
     ),
-    indirect=['_playbook_file'],
+    indirect=["_playbook_file"],
 )
-@pytest.mark.usefixtures('_playbook_file')
-def test_including_wrong_nested_jinja(runner):
+@pytest.mark.usefixtures("_playbook_file")
+def test_including_wrong_nested_jinja(runner: Runner) -> None:
+    """Check that broken Jinja nesting produces a violation."""
     rule_violations = runner.run()
-    assert rule_violations[0].rule.id == 'no-jinja-nesting'
+    assert rule_violations[0].rule.id == "no-jinja-nesting"
 
 
 @pytest.mark.parametrize(
-    '_playbook_file',
+    "_playbook_file",
     (
-        pytest.param([SUCCESS_TASK_P], id='file includes non-nested example'),
+        pytest.param([SUCCESS_TASK_P], id="file includes non-nested example"),
         pytest.param(
-            [SUCCESS_TASK_P_M], id='file includes multiline non-nested example'
+            [SUCCESS_TASK_P_M], id="file includes multiline non-nested example"
         ),
-        pytest.param([SUCCESS_TASK_2P], id='file includes nesting far from each other'),
+        pytest.param([SUCCESS_TASK_2P], id="file includes nesting far from each other"),
         pytest.param(
             [SUCCESS_TASK_2P_M],
-            id='file includes multiline nesting far from each other',
+            id="file includes multiline nesting far from each other",
         ),
         pytest.param(
-            [SUCCESS_TASK_C_2P], id='file includes nesting close to each other'
+            [SUCCESS_TASK_C_2P], id="file includes nesting close to each other"
         ),
         pytest.param(
             [SUCCESS_TASK_C_2P_M],
-            id='file includes multiline nesting close to each other',
+            id="file includes multiline nesting close to each other",
         ),
-        pytest.param([SUCCESS_TASK_PRINT], id='file includes print curly braces'),
+        pytest.param([SUCCESS_TASK_PRINT], id="file includes print curly braces"),
     ),
-    indirect=['_playbook_file'],
+    indirect=["_playbook_file"],
 )
-@pytest.mark.usefixtures('_playbook_file')
-def test_including_proper_nested_jinja(runner):
+@pytest.mark.usefixtures("_playbook_file")
+def test_including_proper_nested_jinja(runner: Runner) -> None:
+    """Check that properly balanced Jinja nesting doesn't fail."""
     rule_violations = runner.run()
     assert not rule_violations
