@@ -13,12 +13,12 @@ class TestPackageIsNotLatestRule(unittest.TestCase):
         self.collection.register(PackageIsNotLatestRule())
 
     def test_package_not_latest_positive(self) -> None:
-        success = 'examples/playbooks/package-check-success.yml'
+        success = "examples/playbooks/package-check-success.yml"
         good_runner = Runner(success, rules=self.collection)
-        self.assertEqual([], good_runner.run())
+        assert [] == good_runner.run()
 
     def test_package_not_latest_negative(self) -> None:
-        failure = 'examples/playbooks/package-check-failure.yml'
+        failure = "examples/playbooks/package-check-failure.yml"
         bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(4, len(errs))
+        assert len(errs) == 4
