@@ -2,15 +2,15 @@ import pytest
 
 from ansiblelint.testing import RunFromText
 
-ROLE_TASKS = '''\
+ROLE_TASKS = """\
 ---
 - debug:
     msg: this should fail linting due lack of name
 - debug:  # noqa unnamed-task
     msg: this should pass due to noqa comment
-'''
+"""
 
-ROLE_TASKS_WITH_BLOCK = '''\
+ROLE_TASKS_WITH_BLOCK = """\
 ---
 - name: bad git 1  # noqa git-latest
   action: git a=b c=d
@@ -32,9 +32,9 @@ ROLE_TASKS_WITH_BLOCK = '''\
       action: git a=b c=d
     - name: bad git 8
       action: git a=b c=d
-'''
+"""
 
-PLAYBOOK = '''\
+PLAYBOOK = """\
 - hosts: all
   tasks:
     - name: test hg-latest
@@ -68,16 +68,16 @@ PLAYBOOK = '''\
       command: creates=B chmod 644 A
       tags:
         - skip_ansible_lint
-'''
+"""
 
-ROLE_META = '''\
+ROLE_META = """\
 galaxy_info:  # noqa meta-no-info
   author: your name  # noqa meta-incorrect
   description: missing min_ansible_version and platforms. author default not changed
   license: MIT
-'''
+"""
 
-ROLE_TASKS_WITH_BLOCK_BECOME = '''\
+ROLE_TASKS_WITH_BLOCK_BECOME = """\
 - hosts: localhost
   tasks:
     - name: foo
@@ -86,10 +86,12 @@ ROLE_TASKS_WITH_BLOCK_BECOME = '''\
         - name: bar
           become_user: jonhdaa
           command: "/etc/test.sh"
-'''
+          changed_when: false
+"""
 
 
 def test_role_tasks(default_text_runner: RunFromText) -> None:
+    """Check that role tasks can contain skips."""
     results = default_text_runner.run_role_tasks_main(ROLE_TASKS)
     assert len(results) == 1, results
     assert results[0].linenumber == 2
@@ -97,25 +99,28 @@ def test_role_tasks(default_text_runner: RunFromText) -> None:
 
 
 def test_role_tasks_with_block(default_text_runner: RunFromText) -> None:
+    """Check that blocks in role tasks can contain skips."""
     results = default_text_runner.run_role_tasks_main(ROLE_TASKS_WITH_BLOCK)
     assert len(results) == 4
 
 
 @pytest.mark.parametrize(
-    ('playbook_src', 'results_num'),
+    ("playbook_src", "results_num"),
     (
         (PLAYBOOK, 7),
         (ROLE_TASKS_WITH_BLOCK_BECOME, 0),
     ),
-    ids=('generic', 'with block become inheritance'),
+    ids=("generic", "with block become inheritance"),
 )
 def test_playbook(
     default_text_runner: RunFromText, playbook_src: str, results_num: int
 ) -> None:
+    """Check that playbooks can contain skips."""
     results = default_text_runner.run_playbook(playbook_src)
     assert len(results) == results_num
 
 
 def test_role_meta(default_text_runner: RunFromText) -> None:
+    """Check that role meta can contain skips."""
     results = default_text_runner.run_role_meta_main(ROLE_META)
     assert len(results) == 0
