@@ -5,11 +5,11 @@ from ansiblelint.rules import RulesCollection
 from ansiblelint.rules.TaskNoLocalAction import TaskNoLocalAction
 from ansiblelint.testing import RunFromText
 
-TASK_LOCAL_ACTION = '''
+TASK_LOCAL_ACTION = """
 - name: task example
   local_action:
     module: boto3_facts
-'''
+"""
 
 
 class TestTaskNoLocalAction(unittest.TestCase):
@@ -21,4 +21,4 @@ class TestTaskNoLocalAction(unittest.TestCase):
 
     def test_local_action(self) -> None:
         results = self.runner.run_role_tasks_main(TASK_LOCAL_ACTION)
-        self.assertEqual(1, len(results))
+        assert len(results) == 1
