@@ -11,16 +11,16 @@ from ansiblelint.runner import Runner
 class TestUsingBareVariablesIsDeprecated(unittest.TestCase):
     collection = RulesCollection()
 
-    def setUp(self):
+    def setUp(self) -> None:
         self.collection.register(UsingBareVariablesIsDeprecatedRule())
 
-    def test_file_positive(self):
-        success = 'examples/playbooks/using-bare-variables-success.yml'
+    def test_file_positive(self) -> None:
+        success = "examples/playbooks/using-bare-variables-success.yml"
         good_runner = Runner(success, rules=self.collection)
-        self.assertEqual([], good_runner.run())
+        assert [] == good_runner.run()
 
-    def test_file_negative(self):
-        failure = 'examples/playbooks/using-bare-variables-failure.yml'
+    def test_file_negative(self) -> None:
+        failure = "examples/playbooks/using-bare-variables-failure.yml"
         bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(11, len(errs))
+        assert len(errs) == 11
