@@ -3,14 +3,12 @@
 
 def a_test_filter(a, b):
     """Return a string containing both a and b."""
-    return '{0}:{1}'.format(a, b)
+    return "{0}:{1}".format(a, b)
 
 
-class FilterModule(object):
+class FilterModule:
     """Filter plugin."""
 
     def filters(self):
         """Return filters."""
-        return {
-            'test_filter': a_test_filter
-        }
+        return {"test_filter": a_test_filter}
